@@ -259,7 +259,11 @@ class binance():
         headers = {'X-MBX-APIKEY': self.API_KEY}
         url = urljoin('https://api.binance.com','/api/v3/order/test')
         response = requests.post(url, headers=headers, params=params).json()
-        return response
+        try:
+            response['msg']
+            return False
+        except:
+            return True
    
 class kraken():
     
@@ -444,30 +448,27 @@ class kraken():
             return ('unable to join market')
         return ordre
 
+    def test_order(self):
+        '''Function to create test order'''
+        data={
+            'pair':'BTCEUR',
+            'ordertype':'market',
+            'type':'buy',
+            'volume':1,
+            'validate':1,
+        }
+        #On essaie de transmettre l'ordre au marché
+        try :
+            ordre = self.api.query_private(method='AddOrder',data=data)
+            if ordre["error"]==[]:
+                return True
+            else:
+                return False
+        except:
+            return False
+        
+
 
 
 if __name__=='__main__':
-    broker=Python_Brokers_API.binance()
-
-    #Public data
-    print(
-        broker.price(),
-        broker.get_klines_data(),
-        broker.get_24h_stats(),
-        )
-
-    #To connect api
-    print(
-        broker.connect_key("binance.key")
-    )
-
-    #Private data
-    print(
-        broker.account_information(),
-        broker.get_open_orders(),
-        broker.get_balances(),
-        broker.create_market_order(symbol='BTCUSD',side='buy',quantity=1),
-        broker.create_limit_order(symbol='BTCUSD',side='buy',quantity=1,price=10000),
-        broker.create_take_profit_order(symbol='BTCUSD',side='buy',quantity=1,profitPrice=100000),
-        broker.create_stop_loss_order(symbol='BTCUSD',side='buy',quantity=1,stopPrice=1000),
-    )
+    pass
\ No newline at end of file
